@@ -73,7 +73,7 @@ where
 
         match stmt {
             Stmt::While(w) => {
-                let (purity, val) = w.test.as_bool();
+                let (purity, val) = w.test.cast_to_bool(&self.expr_ctx);
                 if let Known(false) = val {
                     if purity.is_pure() {
                         let changed = UnreachableHandler::preserve_vars(stmt);
@@ -94,7 +94,7 @@ where
             }
             Stmt::For(f) => {
                 if let Some(test) = &mut f.test {
-                    let (purity, val) = test.as_bool();
+                    let (purity, val) = test.cast_to_bool(&self.expr_ctx);
                     if let Known(false) = val {
                         let changed = UnreachableHandler::preserve_vars(&mut f.body);
                         self.changed |= changed;
